@@ -1,12 +1,27 @@
-"""PackageCompat type.
-"""
+"""PackageCompat type."""
+
 from __future__ import annotations
 
 from dataclasses import dataclass, field
 from enum import Enum
 
-UNKNOWN = "UNKNOWN"
-JOINS = ";; "
+
+class ucstr(str):
+	"""Uppercase string."""
+
+	__slots__ = ()
+
+	def __new__(cls, v: str) -> ucstr:
+		"""Create a new ucstr from a str.
+
+		:param str v: string to cast
+		:return ucstr: uppercase string.
+		"""
+		return super().__new__(cls, v.upper())
+
+
+UNKNOWN = ucstr("UNKNOWN")
+JOINS = ucstr(";; ")
 
 
 @dataclass(unsafe_hash=True, order=True)
@@ -19,13 +34,22 @@ class PackageInfo:
 	size: int = -1
 	homePage: str = UNKNOWN
 	author: str = UNKNOWN
-	license: str = UNKNOWN
+	license: ucstr = UNKNOWN
 	licenseCompat: bool = False
 	errorCode: int = 0
 
-	def __post_init__(self):
+	def __post_init__(self) -> None:
+		"""Set the namever once the object is initialised."""
 		self.namever = f"{self.name}-{self.version}"
 
+	def get_filtered_dict(self, hide_output_parameters: list[ucstr]) -> dict:
+		"""Return a filtered dictionary of the object.
+
+		:param list[ucstr] hide_output_parameters: list of parameters to ignore
+		:return dict: filtered dictionary
+		"""
+		return {k: v for k, v in self.__dict__.items() if k.upper() not in hide_output_parameters}
+
 
 class License(Enum):
 	"""License Enum to hold a set of potential licenses."""
@@ -65,3 +89,6 @@ class License(Enum):
 	PROPRIETARY = 190
 	# No License
 	NO_LICENSE = 200
+
+
+L = License
